@@ -82,9 +82,6 @@
 #' @exportClass dfa
 dfa = function(time.series, window.size.range = c(10, 300),
                npoints = 20, do.plot = TRUE, ...) {
-  window.sizes = c()
-  fluctuation.function = c()
-  
   if ((window.size.range[[2]] < window.size.range[[1]]) ||
       any(window.size.range < 1)) {
     stop("Invalid window size range")
